@@ -7,8 +7,7 @@ from pages.utils import get_placeholders
 from pages.templatetags.pages_tags import PlaceholderNode
 from pages.admin.utils import get_connected, make_inline_admin
 from pages.admin.forms import PageForm
-from pages.admin.views import traduction, get_content, sub_menu
-from pages.admin.views import list_pages_ajax
+from pages.admin.views import traduction, get_content, sub_menu, list_pages_ajax
 from pages.admin.views import change_status, modify_content, delete_content
 from pages.admin.views import move_page
 from pages.permissions import PagePermission
@@ -19,7 +18,7 @@ from django.contrib import admin
 from django.utils.translation import ugettext as _, ugettext_lazy
 from django.utils.encoding import force_unicode
 from django.conf import settings as global_settings
-from django.http import HttpResponseRedirect, Http404
+from django.http import HttpResponseRedirect
 from django.contrib.admin.util import unquote
 from django.contrib.admin.sites import AlreadyRegistered
 if global_settings.USE_I18N:
@@ -92,7 +91,6 @@ class PageAdmin(admin.ModelAdmin):
             'javascript/jquery.query.js',
             'javascript/pages.js',
             'javascript/pages_form.js',
-            'javascript/pages_slug.js',
         )]
 
     def urls(self):
