@@ -22,7 +22,8 @@ class UnitTestCase(TestCase):
 
     def test_date_ordering(self):
         """Test page date ordering feature."""
-        self.set_setting("PAGE_USE_SITE_ID", False)
+        from pages import settings as pages_settings
+        setattr(pages_settings, "PAGE_USE_SITE_ID", False)
         author = User.objects.all()[0]
         yesterday = datetime.datetime.now() - datetime.timedelta(days=1)
         now = datetime.datetime.now()
@@ -78,7 +79,8 @@ class UnitTestCase(TestCase):
 
     def test_page_caculated_status(self):
         """Test calculated status property."""
-        self.set_setting("PAGE_SHOW_START_DATE", True)
+        from pages import settings as pages_settings
+        setattr(pages_settings, "PAGE_SHOW_START_DATE", True)
         yesterday = datetime.datetime.now() - datetime.timedelta(days=1)
         tomorrow = datetime.datetime.now() + datetime.timedelta(days=1)
 
@@ -88,13 +90,14 @@ class UnitTestCase(TestCase):
         self.assertEqual(page.calculated_status, Page.DRAFT)
         page.publication_date = yesterday
         self.assertEqual(page.calculated_status, Page.PUBLISHED)
-        self.set_setting("PAGE_SHOW_END_DATE", True)
+        setattr(pages_settings, "PAGE_SHOW_END_DATE", True)
         page.publication_end_date = yesterday
         self.assertEqual(page.calculated_status, Page.EXPIRED)
 
     def test_placeholder_inherit_content(self):
         """Test placeholder content inheritance between pages."""
-        self.set_setting("PAGE_USE_SITE_ID", False)
+        from pages import settings as pages_settings
+        setattr(pages_settings, "PAGE_USE_SITE_ID", False)
         author = User.objects.all()[0]
         p1 = self.new_page(content={'inher':'parent-content'})
         p2 = self.new_page()
@@ -129,7 +132,7 @@ class UnitTestCase(TestCase):
         self.assertEqual(template.render(context), page.title())
 
 
-        # to be sure to raise an errors in parse template content
+        # error in parse template content
         setattr(settings, "DEBUG", True)
 
         page = self.new_page({'wrong': '{% wrong %}'})
@@ -178,7 +181,8 @@ class UnitTestCase(TestCase):
 
     def test_placeholder_untranslated_content(self):
         """Test placeholder untranslated content."""
-        self.set_setting("PAGE_USE_SITE_ID", False)
+        from pages import settings as pages_settings
+        setattr(pages_settings, "PAGE_USE_SITE_ID", False)
         page = self.new_page(content={})
         placeholder = PlaceholderNode('untrans', page='p', untranslated=True)
         placeholder.save(page, 'fr-ch', 'test-content', True)
@@ -386,7 +390,9 @@ class UnitTestCase(TestCase):
         Test that get_slug_and_relative_path doesn't strip the language
         2 times from the path.
         """
-        self.set_setting("PAGE_USE_LANGUAGE_PREFIX", True)
+        from pages import settings as pages_settings
+        old_value = getattr(pages_settings, "PAGE_USE_LANGUAGE_PREFIX")
+        setattr(pages_settings, "PAGE_USE_LANGUAGE_PREFIX", True)
 
         path = 'en-us/path/path/slug'
         slug, path, lang = get_slug_and_relative_path(path)
@@ -399,12 +405,16 @@ class UnitTestCase(TestCase):
         self.assertEqual(path, 'path/path/slug')
         self.assertEqual(lang, None)
 
+        setattr(pages_settings, "PAGE_USE_LANGUAGE_PREFIX", old_value)
+
     def test_default_view_with_language_prefix(self):
         """
         Test that everything is working with the language prefix option
         activated.
         """
-        self.set_setting("PAGE_USE_LANGUAGE_PREFIX", True)
+        from pages import settings as pages_settings
+        old_value = getattr(pages_settings, "PAGE_USE_LANGUAGE_PREFIX")
+        setattr(pages_settings, "PAGE_USE_LANGUAGE_PREFIX", True)
 
         from pages.views import details
         req = get_request_mock()
@@ -426,43 +436,10 @@ class UnitTestCase(TestCase):
         self.assertEqual(details(req, only_context=True)['current_page'],
             page2)
 
-        self.set_setting("PAGE_USE_LANGUAGE_PREFIX", False)
+
+        setattr(pages_settings, "PAGE_USE_LANGUAGE_PREFIX", old_value)
 
         req.path = page2.get_url_path()
         self.assertEqual(details(req, only_context=True)['current_page'],
             page2)
 
-    def test_root_page_hidden_slug(self):
-        """
-        Check that the root works properly in every case.
-        """
-        page1 = self.new_page(content={'slug':'page1'})
-        self.set_setting("PAGE_USE_LANGUAGE_PREFIX", False)
-        self.set_setting("PAGE_HIDE_ROOT_SLUG", True)
-        self.assertEqual(page1.is_first_root(), True)
-        self.assertEqual(page1.get_url_path(), '/pages/')
-
-        self.set_setting("PAGE_USE_LANGUAGE_PREFIX", True)
-        self.assertEqual(page1.get_url_path(), '/pages/en-us/')
-
-        self.set_setting("PAGE_HIDE_ROOT_SLUG", False)
-        page1.invalidate()
-        self.assertEqual(page1.get_url_path(), '/pages/en-us/page1')
-
-        self.set_setting("PAGE_USE_LANGUAGE_PREFIX", False)
-        self.assertEqual(page1.get_url_path(), '/pages/page1')
-
-    def test_revision_depth(self):
-        """
-        Check that PAGE_CONTENT_REVISION_DEPTH works.
-        """
-        page1 = self.new_page(content={'slug':'page1'})
-        self.set_setting("PAGE_CONTENT_REVISION_DEPTH", 3)
-        Content.objects.create_content_if_changed(page1, 'en-us', 'rev-test', 'rev1')
-        Content.objects.create_content_if_changed(page1, 'en-us', 'rev-test', 'rev2')
-        Content.objects.create_content_if_changed(page1, 'en-us', 'rev-test', 'rev3')
-        Content.objects.create_content_if_changed(page1, 'en-us', 'rev-test', 'rev4')
-        self.assertEqual(Content.objects.filter(type='rev-test').count(), 3)
-        self.assertEqual(
-            Content.objects.filter(type='rev-test').latest('creation_date').body,
-            'rev4')
